@@ -2,11 +2,12 @@ import hashlib
 import json
 import requests
 from agileutil.util import local_ip
-import time
 
 
 class Instance(object):
 
+    __slots__ = ('service', 'address', 'port')
+
     def __init__(self, service, address, port):
         self.service = service
         self.address = address
@@ -15,6 +16,8 @@ class Instance(object):
 
 class ConsulApi(object):
 
+    __slots__ = ('host', 'port', 'baseUrl', 'token', 'timeout')
+
     def __init__(self, host: str, port: int):
         self.host = host
         self.port = port
