@@ -3,8 +3,10 @@ import asyncio
 class EventLoop(object):
     @classmethod
     def runUntilComplete(self, asyncFunc):
+        tasks = [ asyncFunc ]
         loop = asyncio.new_event_loop() 
         asyncio.set_event_loop(loop)
         loop = asyncio.get_event_loop()
-        loop.run_until_complete( asyncFunc )
+        loop.run_until_complete( asyncio.gather(*tasks) )
+        loop.run_forever()
         loop.close()
\ No newline at end of file
