@@ -1,6 +1,8 @@
 
 class HttpRequest(object):
 
+    __slots__ = ('method', 'uri', 'httpVersion', 'body', 'headers', 'data')
+
     def __init__(self) -> None:
         super().__init__()
         self.method = ''
@@ -8,4 +10,7 @@ class HttpRequest(object):
         self.httpVersion = ''
         self.body = ''
         self.headers = {}
-        self.data = {}
\ No newline at end of file
+        self.data = {}
+
+    def setBody(self, body):
+        self.body = body
\ No newline at end of file
